==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/finspace/kotlin/inputs/KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.finspace.kotlin.inputs

import com.pulumi.aws.finspace.inputs.KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property from First port in the range.
 * @property to Last port in the range.
 */
public data class
KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs(
    public val from: Output<Int>,
    public val to: Output<Int>,
) :
    ConvertibleToJava<com.pulumi.aws.finspace.inputs.KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs> {
    override fun toJava():
        com.pulumi.aws.finspace.inputs.KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs =
        com.pulumi.aws.finspace.inputs.KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs.builder()
            .from(from.applyValue({ args0 -> args0 }))
            .to(to.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs].
 */
@PulumiTagMarker
public class
KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgsBuilder
internal constructor() {
    private var from: Output<Int>? = null

    private var to: Output<Int>? = null

    /**
     * @param value First port in the range.
     */
    @JvmName("kqpdcaasosjtobrw")
    public suspend fun from(`value`: Output<Int>) {
        this.from = value
    }

    /**
     * @param value Last port in the range.
     */
    @JvmName("fnxigoabtnslrlbq")
    public suspend fun to(`value`: Output<Int>) {
        this.to = value
    }

    /**
     * @param value First port in the range.
     */
    @JvmName("sjhnsxsphmsbuvfv")
    public suspend fun from(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.from = mapped
    }

    /**
     * @param value Last port in the range.
     */
    @JvmName("mfutygyejgvncnmj")
    public suspend fun to(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.to = mapped
    }

    internal fun build():
        KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs =
        KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs(
            from = from ?: throw PulumiNullFieldException("from"),
            to = to ?: throw PulumiNullFieldException("to"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/finspace/kotlin/inputs/KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.finspace.kotlin.inputs

import com.pulumi.aws.finspace.inputs.KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property from First port in the range.
 * @property to Last port in the range.
 */
public data class
KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs(
    public val from: Output<Int>,
    public val to: Output<Int>,
) :
    ConvertibleToJava<com.pulumi.aws.finspace.inputs.KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs> {
    override fun toJava(): com.pulumi.aws.finspace.inputs.KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs =
        com.pulumi.aws.finspace.inputs.KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs.builder()
            .from(from.applyValue({ args0 -> args0 }))
            .to(to.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs].
 */
@PulumiTagMarker
public class
KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgsBuilder
internal constructor() {
    private var from: Output<Int>? = null

    private var to: Output<Int>? = null

    /**
     * @param value First port in the range.
     */
    @JvmName("fixpywnkgnchensk")
    public suspend fun from(`value`: Output<Int>) {
        this.from = value
    }

    /**
     * @param value Last port in the range.
     */
    @JvmName("hukcjufnrabenqhm")
    public suspend fun to(`value`: Output<Int>) {
        this.to = value
    }

    /**
     * @param value First port in the range.
     */
    @JvmName("kaowvkqwncctjgox")
    public suspend fun from(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.from = mapped
    }

    /**
     * @param value Last port in the range.
     */
    @JvmName("hlbetbbolujwmvsm")
    public suspend fun to(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.to = mapped
    }

    internal fun build(): KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs =
        KxEnvironmentTransitGatewayConfigurationAttachmentNetworkAclConfigurationPortRangeArgs(
            from = from ?: throw PulumiNullFieldException("from"),
            to = to ?: throw PulumiNullFieldException("to"),
        )
}
